@@ -68,6 +68,19 @@ class DBInterface(Generic[T], ILogger):
         self._mongo_db_interface.update(search_filter=search_filter, updated_document=updated_document)
         return self.find(search_filter=search_filter)
 
+    def delete_many(self, search_filter: "Dict[str, Any]", force: bool = False) -> int:
+        """
+        Deletes elements from the DB
+        @param search_filter: The search filter of the elements to delete
+        @param force: if True, permanently delete the elements from the DB, otherwise - just mark them as deleted
+        @return: Number of records that were deleted
+        """
+        if force:
+            delete_result = self._mongo_db_interface.delete(search_filter=search_filter)
+            return delete_result.deleted_count
+        update_result = self._mongo_db_interface.update(search_filter=search_filter, updated_document={"deleted": True})
+        return update_result.modified_count
+
     def delete(self, _id: "UUID", force: bool = False) -> bool:
         """
         Deletes an element from the DB
@@ -76,11 +89,7 @@ class DBInterface(Generic[T], ILogger):
         @return: True on success, False otherwise
         """
         search_filter = {"id": _id}
-        if force:
-            delete_result = self._mongo_db_interface.delete(search_filter=search_filter)
-            return delete_result.deleted_count == 1
-        update_result = self._mongo_db_interface.update(search_filter=search_filter, updated_document={"deleted": True})
-        return update_result.modified_count == 1
+        return self.delete_many(search_filter, force) == 1
 
     def increment_fields(self, *, search_filter: "Dict[str, Any]", fields: "Dict[str, int]") -> bool:
         return self._mongo_db_interface.increment_field(search_filter=search_filter, increment_query=fields)
